#!/bin/bash
#
# Send AWS SNS message with current nshmp-haz-log
#
# Globals are exported from lambda-user-data.sh:
#   - HOME
#   - INSTANCE_ID
#   - send_notification

####
# Run send updates.
# Globals:
#   None
# Arguments:
#   None
# Returns:
#   None
####
main() {
  # Set trap for uncaught errors.
  trap 'error_exit "${BASH_COMMAND}" "$(< run-send-updates-log)"' ERR;

  send_updates 2> run-send-updates-log || \
      error_exit "Could not send updates" "$(< run-send-updates-log)";
}

####
# Send an update with the current nshmp-haz-log.
# Globals:
#   (string) HOME - EC2 home path
#   (string) INSTANCE_ID - The EC2 instance id
# Arguments:
#   None
# Returns:
# None
####
send_updates() {
  local message="
    nshmp-haz update (instance id - ${INSTANCE_ID})

    ----------
    Logs:

    $(tail -15 ${HOME}/${LOG_FILE})
  ";

  send_notification "${message}";
}

####
# Run main
####
main "$@";
